@@ -62,7 +62,7 @@ class PasaffeWindow(Window):
         new_object.finish_initializing(builder, database)
         return new_object
 
-    def finish_initializing(self, builder, database):  # pylint: disable=E1002
+    def finish_initializing(self, builder, database):
         """Set up the main window"""
         super(PasaffeWindow, self).finish_initializing(builder)
 
@@ -1254,8 +1254,9 @@ class PasaffeWindow(Window):
         self.update_find_results(force=True)
 
     def model_get_iter_last(self, model, parent=None):
-        """Returns a Gtk.TreeIter to the last row or None if there aren't any rows.
-        If parent is None, returns a Gtk.TreeIter to the last root row."""
+        """Returns a Gtk.TreeIter to the last row or None if there aren't any
+        rows. If parent is None, returns a Gtk.TreeIter to the last root
+        row."""
         nchild = model.iter_n_children(parent)
         return nchild and model.iter_nth_child(parent, nchild - 1)
 
