@@ -523,7 +523,7 @@ class Blowfish:
         with this method one after the other without any intermediate work.
         Each buffer must be a multiple of 8-octets (64-bits) in length.
         """
-        if type(data) != bytes:
+        if type(data) is not bytes:
             raise RuntimeError("Can only work on 8-bit strings")
         if (len(data) % 8) != 0:
             raise RuntimeError("Can only work with data in 64-bit"
@@ -544,7 +544,7 @@ class Blowfish:
         return result
 
     def decryptCBC(self, data):
-        if type(data) != bytes:
+        if type(data) is not bytes:
             raise RuntimeError("Can only work on 8-bit strings")
         if (len(data) % 8) != 0:
             raise RuntimeError("Can only work with data in 64-bit"
@@ -592,7 +592,7 @@ class Blowfish:
         (belonging to the same logical stream of buffers) can be encrypted
         with this method one after the other without any intermediate work.
         """
-        if type(data) != bytes:
+        if type(data) is not bytes:
             raise Exception("Can only work on 8-bit strings")
         result = bytearray()
         for ch in data:
