@@ -40,6 +40,9 @@ from . pasaffeconfig import get_version  # noqa: E402
 
 class PassSafeFile:
 
+    # Iterations value obtained from Password Safe v3.68
+    MIN_HASH_ITERATIONS = 262144
+
     def __init__(self, filename=None, password=None, req_cipher='Twofish',
                  fixup=True):
         '''Reads a Password Safe v3 file'''
@@ -105,7 +108,7 @@ class PassSafeFile:
 
     def new_db(self, password):
         '''Creates a new database in memory'''
-        self.keys['ITER'] = 2048
+        self.keys['ITER'] = self.MIN_HASH_ITERATIONS
 
         self.new_keys(password)
 
@@ -540,10 +543,6 @@ class PassSafeFile:
     def _readkeys(self, password):
         self.keys['SALT'] = self.dbfile.read(32)
         self.keys['ITER'] = struct.unpack("<i", self.dbfile.read(4))[0]
-        # Sanity check so we don't gobble up massive amounts of ram
-        if self.keys['ITER'] > 100000:
-            raise RuntimeError("Too many iterations: %s. Aborting." %
-                               self.keys['ITER'])
         logger.debug("Number of iters is %d" % self.keys['ITER'])
         self.keys['HP'] = self.dbfile.read(32)
         # logger.debug("hp is %s" % self.keys['HP'])
@@ -588,7 +587,7 @@ class PassSafeFile:
     def _readheader(self):
         self.cipher.set_key(self.keys['K'])
 
-        while(1):
+        while (1):
             status, field_type, field_data = self._readfield()
             if status is False:
                 raise RuntimeError("Malformed file, "
@@ -645,7 +644,7 @@ class PassSafeFile:
 
         record = {}
 
-        while(1):
+        while (1):
             status, field_type, field_data = self._readfield()
             if status is False:
                 break
@@ -806,6 +805,12 @@ class PassSafeFile:
                 self.records[uuid][5] = self.records[uuid][5].replace(
                     "\r\n", "\n")
 
+        # Update the number of iterations to the current safe default
+        if self.keys['ITER'] < self.MIN_HASH_ITERATIONS:
+            logger.debug("Updating iterations from %d to %d" %
+                         (self.keys['ITER'], self.MIN_HASH_ITERATIONS))
+            self.keys['ITER'] = self.MIN_HASH_ITERATIONS
+
     def _presave_fixup(self, uuid, field):
         '''Performs some cleanup before saving certain databases'''
 
