@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
-# Copyright (C) 2011-2013 Marc Deslauriers <marc.deslauriers@canonical.com>
+# Copyright (C) 2011-2024 Marc Deslauriers <marc.deslauriers@canonical.com>
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
@@ -20,14 +20,16 @@ import subprocess
 
 
 class TestPylint(unittest.TestCase):
-    def test_project_errors_only(self):
-        '''run pylint in error only mode
+    def test_pasaffe_errors_only(self):
+        '''run pylint in error only mode'''
+        rc = subprocess.call(["pylint", '-E', 'pasaffe'])
+        self.assertEqual(rc, 0)
 
-        your code may well work even with pylint errors
-        but have some unusual code'''
-        subprocess.call(["pylint", '-E', 'pasaffe'])
+    def test_pasaffe_lib_errors_only(self):
+        '''run pylint in error only mode'''
+        rc = subprocess.call(["pylint", '-E', 'pasaffe_lib'])
+        self.assertEqual(rc, 0)
 
 
 if __name__ == '__main__':
-    'you will get better results with nosetests'
     unittest.main()
