@@ -32,6 +32,13 @@ class TestPasswordSafe331(unittest.TestCase):
     def test_num_entries(self):
         self.assertEqual(len(self.passfile.records), 3)
 
+    def test_num_iter(self):
+        # The actual test database has less iterations, we're testing
+        # here to make sure the minimum number got updated when the DB was
+        # opened
+        self.assertEqual(self.passfile.keys['ITER'],
+                         self.passfile.MIN_HASH_ITERATIONS)
+
     def test_empty_folders(self):
 
         empty_folders = [['emptygroup1'],
