@@ -583,6 +583,9 @@ class TestReadDB(unittest.TestCase):
         self.assertTrue(6 not in self.passfile.records[uuid_hex])
         self.assertEqual(self.passfile.records[uuid_hex][5], crlf)
 
+        # Set a low number of iterations to see if it gets increased
+        self.passfile.keys['ITER'] = 2048
+
         # Now do the postread fixup
         self.passfile._postread_fixup()
 
@@ -591,6 +594,9 @@ class TestReadDB(unittest.TestCase):
         self.assertEqual(self.passfile.records[uuid_hex][5], lf)
         self.assertEqual(self.passfile.records[uuid_hex][6], '')
 
+        self.assertEqual(self.passfile.keys['ITER'],
+                         self.passfile.MIN_HASH_ITERATIONS)
+
         # OK, do the presave fixup
         self.assertEqual(self.passfile._presave_fixup(uuid_hex, 5), crlf)
 
